* Content Security Policy
* Cookie
* Cross-Origin Resource Sharing
* HTTP Public Key Pinning
* Redirection
* Referrer Policy
* Subresource Integrity
* X-Content-Type-Options
* X-Frame-Options
* X-XSS-Protection
